@@ -47,6 +47,7 @@ class RuntimeConfigurationObject:
         self.type_registry = {}
         self.clear_type_registry()
         self.active_spec_version_id = None
+        self.chain_id = None
 
     @classmethod
     def convert_type_string(cls, name):
@@ -55,8 +56,9 @@ class RuntimeConfigurationObject:
         name = re.sub(r'<T>', "", name)
         name = re.sub(r'<T as Trait>::', "", name)
         name = re.sub(r'<T as Config>::', "", name)
+        name = re.sub(r'<T as Config<I>>::', "", name)
         name = re.sub(r'\n', "", name)
-        name = re.sub(r'(grandpa|session|slashing)::', "", name)
+        name = re.sub(r'(grandpa|session|slashing|limits)::', "", name)
 
         if name == '()':
             return "Null"
@@ -186,6 +188,9 @@ class RuntimeConfigurationObject:
         # Set runtime ID if set
         self.active_spec_version_id = type_registry.get('runtime_id')
 
+        # Set chain ID if set
+        self.chain_id = type_registry.get('chain_id')
+
         # Set versioning
         if 'versioning' in type_registry:
             self.type_registry['versioning'] = type_registry.get('versioning')
@@ -304,6 +309,8 @@ class ScaleDecoder(ABC):
         self.data = data
         self.raw_value = ''
         self.value = None
+        self.data_start_offset = None
+        self.data_end_offset = None
 
     @classmethod
     def build_type_mapping(cls):
@@ -346,12 +353,17 @@ class ScaleDecoder(ABC):
         self.raw_value += data.hex()
         return data
 
+    def get_used_bytes(self):
+        return self.data.data[self.data_start_offset:self.data_end_offset]
+
     @abstractmethod
     def process(self):
         raise NotImplementedError
 
     def decode(self, check_remaining=True):
+        self.data_start_offset = self.data.offset
         self.value = self.process()
+        self.data_end_offset = self.data.offset
 
         if check_remaining and self.data.offset != self.data.length:
             raise RemainingScaleBytesNotEmptyException('Current offset: {} / length: {}'.format(self.data.offset, self.data.length))
